|travis| |appveyor|

kthbuild
=========

Knuth Building Tools (Alpha version)

Getting started 
---------------

Stable version:

.. code-block:: bash

    $ pip install --upgrade kthbuild

Development version:

.. code-block:: bash

    $ pip install --upgrade --index-url https://test.pypi.org/pypi/ kthbuild

.. |travis| image:: https://travis-ci.org/k-nuth/kthbuild.svg?branch=master
 		   :target: https://travis-ci.org/k-nuth/kthbuild
 		   
.. |appveyor| image:: https://ci.appveyor.com/api/projects/status/github/k-nuth/kthbuild?branch=master&svg=true
  		     :target: https://ci.appveyor.com/project/k-nuth/kthbuild?branch=master


